seqtools.divide_sequence_elements_by_greatest_common_divisor
============================================================

.. autofunction:: abjad.tools.seqtools.divide_sequence_elements_by_greatest_common_divisor
